@@ -10,7 +10,7 @@ use rsvg_internals;
 use self::rsvg_internals::surface_utils::shared_surface::{SharedImageSurface, SurfaceType};
 
 use std::env;
-use std::fs::File;
+use std::fs::{self, File};
 use std::io::BufReader;
 use std::path::PathBuf;
 
@@ -23,7 +23,9 @@ pub fn load_svg(input: &'static [u8]) -> SvgHandle {
     let bytes = glib::Bytes::from_static(input);
     let stream = gio::MemoryInputStream::new_from_bytes(&bytes);
 
-    Loader::new().read_stream(&stream, None::<&gio::File>, None::<&gio::Cancellable>).unwrap()
+    Loader::new()
+        .read_stream(&stream, None::<&gio::File>, None::<&gio::Cancellable>)
+        .unwrap()
 }
 
 #[derive(Copy, Clone)]
@@ -47,7 +49,7 @@ pub fn render_document<F: FnOnce(&cairo::Context)>(
         Ok(renderer.render_document(&cr, &viewport)?)
     };
 
-    res.and_then(|_| Ok(SharedImageSurface::new(output, SurfaceType::SRgb)?))
+    res.and_then(|_| Ok(SharedImageSurface::wrap(output, SurfaceType::SRgb)?))
 }
 
 pub fn output_dir() -> PathBuf {
@@ -56,6 +58,8 @@ pub fn output_dir() -> PathBuf {
             .expect(r#"OUT_DIR is not set, please set it or run under "cargo test""#),
     );
 
+    fs::create_dir_all(&path).expect("could not create output directory for tests");
+
     println!("outputting to {}", path.to_string_lossy());
 
     path
@@ -96,7 +100,7 @@ pub fn compare_to_file(
     let mut fixture_file = BufReader::new(file);
 
     let expected = cairo::ImageSurface::create_from_png(&mut fixture_file).unwrap();
-    let expected_surf = SharedImageSurface::new(expected, SurfaceType::SRgb).unwrap();
+    let expected_surf = SharedImageSurface::wrap(expected, SurfaceType::SRgb).unwrap();
 
     let diff = compare_surfaces(output_surf, &expected_surf).unwrap();
 
