@@ -2,7 +2,9 @@
 
 use std::error;
 use std::fmt;
+use std::io;
 use std::ops::Deref;
+use std::path::{Path, PathBuf};
 use url::Url;
 
 use crate::error::HrefError;
@@ -35,12 +37,6 @@ pub enum AllowedUrlError {
     /// or in one directory below the base file.
     NotSiblingOrChildOfBaseFile,
 
-    /// Loaded file:// URLs cannot have a query part, e.g. `file:///foo?blah`
-    NoQueriesAllowed,
-
-    /// URLs may not have fragment identifiers at this stage
-    NoFragmentIdentifierAllowed,
-
     /// Error when obtaining the file path or the base file path
     InvalidPath,
 
@@ -63,17 +59,6 @@ impl AllowedUrl {
             return Ok(AllowedUrl(url));
         }
 
-        // Queries are not allowed.
-        if url.query().is_some() {
-            return Err(AllowedUrlError::NoQueriesAllowed);
-        }
-
-        // Fragment identifiers are not allowed.  They should have been stripped
-        // upstream, by NodeId.
-        if url.fragment().is_some() {
-            return Err(AllowedUrlError::NoFragmentIdentifierAllowed);
-        }
-
         // All other sources require a base url
         if base_url.is_none() {
             return Err(AllowedUrlError::BaseRequired);
@@ -96,26 +81,6 @@ impl AllowedUrl {
             return Err(AllowedUrlError::DisallowedScheme);
         }
 
-        // The rest of this function assumes file: URLs; guard against
-        // incorrect refactoring.
-        assert!(url.scheme() == "file");
-
-        // If we have a base_uri of "file:///foo/bar.svg", and resolve an href of ".",
-        // Url.parse() will give us "file:///foo/".  We don't want that, so check
-        // if the last path segment is empty - it will not be empty for a normal file.
-
-        if let Some(segments) = url.path_segments() {
-          if segments
-                .last()
-                .expect("URL path segments always contain at last 1 element")
-                .is_empty()
-            {
-                return Err(AllowedUrlError::NotSiblingOrChildOfBaseFile);
-            }
-        } else {
-            unreachable!("the file: URL cannot have an empty path");
-        }
-
         // We have two file: URIs.  Now canonicalize them (remove .. and symlinks, etc.)
         // and see if the directories match
 
@@ -133,17 +98,13 @@ impl AllowedUrl {
 
         let base_parent = base_parent.unwrap();
 
-        let path_canon = url_path
-            .canonicalize()
-            .map_err(|_| AllowedUrlError::CanonicalizationError)?;
-        let parent_canon = base_parent
-            .canonicalize()
-            .map_err(|_| AllowedUrlError::CanonicalizationError)?;
+        let url_canon =
+            canonicalize(&url_path).map_err(|_| AllowedUrlError::CanonicalizationError)?;
+        let parent_canon =
+            canonicalize(&base_parent).map_err(|_| AllowedUrlError::CanonicalizationError)?;
 
-        if path_canon.starts_with(parent_canon) {
-            // Finally, convert the canonicalized path back to a URL.
-            let path_to_url = Url::from_file_path(path_canon).unwrap();
-            Ok(AllowedUrl(path_to_url))
+        if url_canon.starts_with(parent_canon) {
+            Ok(AllowedUrl(url))
         } else {
             Err(AllowedUrlError::NotSiblingOrChildOfBaseFile)
         }
@@ -168,22 +129,32 @@ impl error::Error for AllowedUrlError {}
 
 impl fmt::Display for AllowedUrlError {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        use AllowedUrlError::*;
-        match self {
-            HrefParseError(e) => write!(f, "URL parse error: {}", e),
-            BaseRequired => write!(f, "base required"),
-            DifferentUriSchemes => write!(f, "different URI schemes"),
-            DisallowedScheme => write!(f, "disallowed scheme"),
-            NotSiblingOrChildOfBaseFile => write!(f, "not sibling or child of base file"),
-            NoQueriesAllowed => write!(f, "no queries allowed"),
-            NoFragmentIdentifierAllowed => write!(f, "no fragment identifier allowed"),
-            InvalidPath => write!(f, "invalid path"),
-            BaseIsRoot => write!(f, "base is root"),
-            CanonicalizationError => write!(f, "canonicalization error"),
+        match *self {
+            AllowedUrlError::HrefParseError(e) => write!(f, "href parse error: {}", e),
+            AllowedUrlError::BaseRequired => write!(f, "base required"),
+            AllowedUrlError::DifferentURISchemes => write!(f, "different URI schemes"),
+            AllowedUrlError::DisallowedScheme => write!(f, "disallowed scheme"),
+            AllowedUrlError::NotSiblingOrChildOfBaseFile => {
+                write!(f, "not sibling or child of base file")
+            }
+            AllowedUrlError::InvalidPath => write!(f, "invalid path"),
+            AllowedUrlError::BaseIsRoot => write!(f, "base is root"),
+            AllowedUrlError::CanonicalizationError => write!(f, "canonicalization error"),
         }
     }
 }
 
+// For tests, we don't want to touch the filesystem.  In that case,
+// assume that we are being passed canonical file names.
+#[cfg(not(test))]
+fn canonicalize<P: AsRef<Path>>(path: P) -> Result<PathBuf, io::Error> {
+    path.as_ref().canonicalize()
+}
+#[cfg(test)]
+fn canonicalize<P: AsRef<Path>>(path: P) -> Result<PathBuf, io::Error> {
+    Ok(path.as_ref().to_path_buf())
+}
+
 /// Parsed result of an href from an SVG or CSS file
 ///
 /// Sometimes in SVG element references (e.g. the `href` in the `<feImage>` element) we
@@ -216,7 +187,7 @@ impl Fragment {
     }
 
     pub fn uri(&self) -> Option<&str> {
-        self.0.as_ref().map(|s| s.as_str())
+        self.0.as_deref()
     }
 
     pub fn fragment(&self) -> &str {
@@ -226,12 +197,7 @@ impl Fragment {
 
 impl fmt::Display for Fragment {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
-        write!(
-            f,
-            "{}#{}",
-            self.0.as_ref().map(String::as_str).unwrap_or(""),
-            self.1
-        )
+        write!(f, "{}#{}", self.uri().unwrap_or(""), self.fragment())
     }
 }
 
@@ -268,8 +234,6 @@ impl Href {
 mod tests {
     use super::*;
 
-    use std::path::PathBuf;
-
     #[test]
     fn disallows_relative_file_with_no_base_file() {
         assert_eq!(
@@ -320,137 +284,56 @@ mod tests {
         );
     }
 
-    fn url_from_test_fixtures(filename_relative_to_librsvg_srcdir: &str) -> Url {
-        let path = PathBuf::from(filename_relative_to_librsvg_srcdir);
-        let absolute = path
-            .canonicalize()
-            .expect("files from test fixtures are supposed to canonicalize");
-        Url::from_file_path(absolute).unwrap()
-    }
-
     #[test]
     fn allows_relative() {
-        let resolved = AllowedUrl::from_href(
-            "foo.svg",
-            Some(url_from_test_fixtures("../tests/fixtures/loading/bar.svg")).as_ref()
-        ).unwrap();
-
-        let resolved_str = resolved.as_str();
-        assert!(resolved_str.ends_with("/loading/foo.svg"));
+        assert_eq!(
+            AllowedUrl::from_href(
+                "foo.svg",
+                Some(Url::parse("file:///example/bar.svg").unwrap()).as_ref()
+            )
+            .unwrap()
+            .as_ref(),
+            "file:///example/foo.svg",
+        );
     }
 
     #[test]
     fn allows_sibling() {
-        let sibling = url_from_test_fixtures("../tests/fixtures/loading/foo.svg");
-        let resolved = AllowedUrl::from_href(
-            sibling.as_str(),
-            Some(url_from_test_fixtures("../tests/fixtures/loading/bar.svg")).as_ref()
-        ).unwrap();
-        
-        let resolved_str = resolved.as_str();
-        assert!(resolved_str.ends_with("/loading/foo.svg"));
+        assert_eq!(
+            AllowedUrl::from_href(
+                "file:///example/foo.svg",
+                Some(Url::parse("file:///example/bar.svg").unwrap()).as_ref()
+            )
+            .unwrap()
+            .as_ref(),
+            "file:///example/foo.svg",
+        );
     }
 
     #[test]
     fn allows_child_of_sibling() {
-        let child_of_sibling = url_from_test_fixtures("../tests/fixtures/loading/subdir/baz.svg");
-        let resolved = AllowedUrl::from_href(
-            child_of_sibling.as_str(),
-            Some(url_from_test_fixtures("../tests/fixtures/loading/bar.svg")).as_ref()
-        ).unwrap();
-        
-        let resolved_str = resolved.as_str();
-        assert!(resolved_str.ends_with("/loading/subdir/baz.svg"));
+        assert_eq!(
+            AllowedUrl::from_href(
+                "file:///example/subdir/foo.svg",
+                Some(Url::parse("file:///example/bar.svg").unwrap()).as_ref()
+            )
+            .unwrap()
+            .as_ref(),
+            "file:///example/subdir/foo.svg",
+        );
     }
 
-    // Ignore on Windows since we test for /etc/passwd
-    #[cfg(unix)]
     #[test]
     fn disallows_non_sibling() {
         assert_eq!(
             AllowedUrl::from_href(
                 "file:///etc/passwd",
-                Some(url_from_test_fixtures("../tests/fixtures/loading/bar.svg")).as_ref()
+                Some(Url::parse("file:///example/bar.svg").unwrap()).as_ref()
             ),
             Err(AllowedUrlError::NotSiblingOrChildOfBaseFile)
         );
     }
 
-    #[test]
-    fn disallows_queries() {
-        match AllowedUrl::from_href(
-            ".?../../../../../../../../../../etc/passwd",
-            Some(url_from_test_fixtures("../tests/fixtures/loading/bar.svg")).as_ref(),
-        ) {
-            Err(AllowedUrlError::NoQueriesAllowed) => (),
-            _ => panic!(),
-        }
-    }
-
-    #[test]
-    fn disallows_weird_relative_uris() {
-        let base_url = url_from_test_fixtures("../tests/fixtures/loading/bar.svg");
-
-        assert!(
-            AllowedUrl::from_href(
-                ".@../../../../../../../../../../etc/passwd",
-                Some(&base_url),
-            ).is_err()
-        );
-        assert!(
-            AllowedUrl::from_href(
-                ".$../../../../../../../../../../etc/passwd",
-                Some(&base_url),
-            ).is_err()
-        );
-        assert!(
-            AllowedUrl::from_href(
-                ".%../../../../../../../../../../etc/passwd",
-                Some(&base_url),
-            ).is_err()
-        );
-        assert!(
-            AllowedUrl::from_href(
-                ".*../../../../../../../../../../etc/passwd",
-                Some(&base_url),
-            ).is_err()
-        );
-        assert!(
-            AllowedUrl::from_href(
-                "~/../../../../../../../../../../etc/passwd",
-                Some(&base_url),
-            ).is_err()
-        );
-    }
-
-    #[test]
-    fn disallows_dot_sibling() {
-        println!("cwd: {:?}", std::env::current_dir());
-        let base_url = url_from_test_fixtures("../tests/fixtures/loading/bar.svg");
-
-        match AllowedUrl::from_href(".", Some(&base_url)) {
-            Err(AllowedUrlError::NotSiblingOrChildOfBaseFile) => (),
-            _ => panic!(),
-        }
-
-        match AllowedUrl::from_href(".#../../../../../../../../../../etc/passwd", Some(&base_url)) {
-            Err(AllowedUrlError::NoFragmentIdentifierAllowed) => (),
-            _ => panic!(),
-        }
-    }
-
-    #[test]
-    fn disallows_fragment() {
-        // AllowedUrl::from_href() explicitly disallows fragment identifiers.
-        // This is because they should have been stripped before calling that function,
-        // by the Iri machinery.
-
-        match AllowedUrl::from_href("bar.svg#fragment", Some(Url::parse("https://example.com/foo.svg").unwrap()).as_ref()) {
-            Err(AllowedUrlError::NoFragmentIdentifierAllowed) => (),
-            _ => panic!(),
-        }
-     }
-
     #[test]
     fn parses_href() {
         assert_eq!(
