@@ -8,6 +8,7 @@ use std::collections::{HashMap, HashSet};
 use std::fmt;
 use std::ops::Deref;
 
+use crate::attributes::Attributes;
 use crate::bbox::BoundingBox;
 use crate::cond::{RequiredExtensions, RequiredFeatures, SystemLanguage};
 use crate::css::{Declaration, Origin};
@@ -40,7 +41,6 @@ use crate::node::*;
 use crate::parsers::Parse;
 use crate::pattern::Pattern;
 use crate::properties::{ComputedValues, SpecifiedValues};
-use crate::property_bag::PropertyBag;
 use crate::shapes::{Circle, Ellipse, Line, Path, Polygon, Polyline, Rect};
 use crate::structure::{ClipPath, Group, Link, Mask, NonRendering, Svg, Switch, Symbol, Use};
 use crate::style::Style;
@@ -70,10 +70,10 @@ use crate::transform::Transform;
 pub type ElementResult = Result<(), ElementError>;
 
 pub trait SetAttributes {
-    /// Sets per-element attributes from the `pbag`
+    /// Sets per-element attributes.
     ///
-    /// Each element is supposed to iterate the `pbag`, and parse any attributes it needs.
-    fn set_attributes(&mut self, _pbag: &PropertyBag<'_>) -> ElementResult {
+    /// Each element is supposed to iterate the `attributes`, and parse any ones it needs.
+    fn set_attributes(&mut self, _attributes: &Attributes) -> ElementResult {
         Ok(())
     }
 }
@@ -99,6 +99,7 @@ pub struct ElementInner<T: SetAttributes + Draw> {
     element_name: QualName,
     id: Option<String>,    // id attribute from XML element
     class: Option<String>, // class attribute from XML element
+    attributes: Attributes,
     specified_values: SpecifiedValues,
     important_styles: HashSet<QualName>,
     result: ElementResult,
@@ -110,10 +111,53 @@ pub struct ElementInner<T: SetAttributes + Draw> {
 }
 
 impl<T: SetAttributes + Draw> ElementInner<T> {
+    fn new(
+        element_name: QualName,
+        id: Option<String>,
+        class: Option<String>,
+        attributes: Attributes,
+        result: Result<(), ElementError>,
+        element_impl: T,
+    ) -> ElementInner<T> {
+        let mut e = Self {
+            element_name,
+            id,
+            class,
+            attributes,
+            specified_values: Default::default(),
+            important_styles: Default::default(),
+            result,
+            transform: Default::default(),
+            values: Default::default(),
+            cond: true,
+            style_attr: String::new(),
+            element_impl,
+        };
+
+        e.save_style_attribute();
+
+        let mut set_attributes = || -> Result<(), ElementError> {
+            e.set_transform_attribute()?;
+            e.set_conditional_processing_attributes()?;
+            e.set_presentation_attributes()?;
+            Ok(())
+        };
+
+        if let Err(error) = set_attributes() {
+            e.set_error(error);
+        }
+
+        e
+    }
+
     fn element_name(&self) -> &QualName {
         &self.element_name
     }
 
+    fn get_attributes(&self) -> &Attributes {
+        &self.attributes
+    }
+
     fn get_id(&self) -> Option<&str> {
         self.id.as_deref()
     }
@@ -142,71 +186,65 @@ impl<T: SetAttributes + Draw> ElementInner<T> {
         self.transform
     }
 
-    fn save_style_attribute(&mut self, pbag: &PropertyBag<'_>) {
-        let result = pbag
-            .iter()
-            .find(|(attr, _)| attr.expanded() == expanded_name!("", "style"))
-            .map(|(_, value)| value);
-        if let Some(value) = result {
-            self.style_attr.push_str(value);
-        }
+    fn save_style_attribute(&mut self) {
+        self.style_attr.push_str(
+            self.attributes
+                .iter()
+                .find(|(attr, _)| attr.expanded() == expanded_name!("", "style"))
+                .map(|(_, value)| value)
+                .unwrap_or(""),
+        );
     }
 
-    fn set_transform_attribute(&mut self, pbag: &PropertyBag<'_>) -> Result<(), ElementError> {
-        let result = pbag
+    fn set_transform_attribute(&mut self) -> Result<(), ElementError> {
+        self.transform = self
+            .attributes
             .iter()
             .find(|(attr, _)| attr.expanded() == expanded_name!("", "transform"))
-            .map(|(attr, value)| {
-                Transform::parse_str(value).attribute(attr).map(|affine| {
-                    self.transform = affine;
-                })
-            });
-        if let Some(transform_result) = result {
-            return transform_result;
-        }
+            .map(|(attr, value)| Transform::parse_str(value).attribute(attr))
+            .unwrap_or_else(|| Ok(Transform::default()))?;
 
         Ok(())
     }
 
-    fn set_conditional_processing_attributes(
-        &mut self,
-        pbag: &PropertyBag<'_>,
-    ) -> Result<(), ElementError> {
+    fn set_conditional_processing_attributes(&mut self) -> Result<(), ElementError> {
         let mut cond = self.cond;
 
-        for (attr, value) in pbag.iter() {
-            let mut parse = || -> Result<_, ValueErrorKind> {
-                match attr.expanded() {
-                    expanded_name!("", "requiredExtensions") if cond => {
-                        cond = RequiredExtensions::from_attribute(value)
-                            .map(|RequiredExtensions(res)| res)?;
-                    }
-
-                    expanded_name!("", "requiredFeatures") if cond => {
-                        cond = RequiredFeatures::from_attribute(value)
-                            .map(|RequiredFeatures(res)| res)?;
-                    }
-
-                    expanded_name!("", "systemLanguage") if cond => {
-                        cond = SystemLanguage::from_attribute(value, &LOCALE)
-                            .map(|SystemLanguage(res)| res)?;
-                    }
-
-                    _ => {}
+        for (attr, value) in self.attributes.iter() {
+            match attr.expanded() {
+                expanded_name!("", "requiredExtensions") if cond => {
+                    cond = RequiredExtensions::from_attribute(value)
+                        .map(|RequiredExtensions(res)| res)
+                        .attribute(attr)?;
                 }
 
-                Ok(cond)
-            };
+                expanded_name!("", "requiredFeatures") if cond => {
+                    cond = RequiredFeatures::from_attribute(value)
+                        .map(|RequiredFeatures(res)| res)
+                        .attribute(attr)?;
+                }
 
-            parse().map(|c| self.cond = c).attribute(attr)?;
+                expanded_name!("", "systemLanguage") if cond => {
+                    cond = SystemLanguage::from_attribute(value, &LOCALE)
+                        .map(|SystemLanguage(res)| res)
+                        .attribute(attr)?;
+                }
+
+                _ => {}
+            }
         }
 
+        self.cond = cond;
+
         Ok(())
     }
 
-    /// Hands the pbag to the node's state, to apply the presentation attributes
-    fn set_presentation_attributes(&mut self, pbag: &PropertyBag<'_>) -> Result<(), ElementError> {
-        match self.specified_values.parse_presentation_attributes(pbag) {
+    /// Hands the `attrs` to the node's state, to apply the presentation attributes.
+    fn set_presentation_attributes(&mut self) -> Result<(), ElementError> {
+        match self
+            .specified_values
+            .parse_presentation_attributes(&self.attributes)
+        {
             Ok(_) => Ok(()),
             Err(e) => {
                 // FIXME: we'll ignore errors here for now.
@@ -261,17 +299,6 @@ impl<T: SetAttributes + Draw> ElementInner<T> {
     }
 }
 
-impl<T: SetAttributes + Draw> SetAttributes for ElementInner<T> {
-    fn set_attributes(&mut self, pbag: &PropertyBag<'_>) -> ElementResult {
-        self.save_style_attribute(pbag);
-
-        self.set_transform_attribute(pbag)
-            .and_then(|_| self.set_conditional_processing_attributes(pbag))
-            .and_then(|_| self.element_impl.set_attributes(pbag))
-            .and_then(|_| self.set_presentation_attributes(pbag))
-    }
-}
-
 impl<T: SetAttributes + Draw> Draw for ElementInner<T> {
     fn draw(
         &self,
@@ -452,21 +479,21 @@ macro_rules! call_inner {
 }
 
 impl Element {
-    /// Takes an XML element name and a list of attribute/value pairs and creates an [`Element`].
+    /// Takes an XML element name and consumes a list of attribute/value pairs to create an [`Element`].
     ///
     /// This operation does not fail.  Unknown element names simply produce a [`NonRendering`]
     /// element.
     ///
     /// [`Element`]: type.Element.html
     /// [`NonRendering`]: ../structure/struct.NonRendering.html
-    pub fn new(name: &QualName, pbag: &PropertyBag) -> Element {
+    pub fn new(name: &QualName, attrs: Attributes) -> Element {
         let mut id = None;
         let mut class = None;
 
-        for (attr, value) in pbag.iter() {
+        for (attr, value) in attrs.iter() {
             match attr.expanded() {
-                expanded_name!("", "id") => id = Some(value),
-                expanded_name!("", "class") => class = Some(value),
+                expanded_name!("", "id") => id = Some(String::from(value)),
+                expanded_name!("", "class") => class = Some(String::from(value)),
                 _ => (),
             }
         }
@@ -497,19 +524,17 @@ impl Element {
 
         //    sizes::print_sizes();
 
-        let mut element = create_fn(name, id, class);
-
-        if let Err(e) = element.set_attributes(pbag) {
-            element.set_error(e);
-        }
-
-        element
+        create_fn(name, attrs, id, class)
     }
 
     pub fn element_name(&self) -> &QualName {
         call_inner!(self, element_name)
     }
 
+    pub fn get_attributes(&self) -> &Attributes {
+        call_inner!(self, get_attributes)
+    }
+
     pub fn get_id(&self) -> Option<&str> {
         call_inner!(self, get_id)
     }
@@ -546,10 +571,6 @@ impl Element {
         call_inner!(self, set_style_attribute);
     }
 
-    fn set_error(&mut self, error: ElementError) {
-        call_inner!(self, set_error, error);
-    }
-
     pub fn is_in_error(&self) -> bool {
         call_inner!(self, is_in_error)
     }
@@ -593,12 +614,6 @@ impl Element {
     }
 }
 
-impl SetAttributes for Element {
-    fn set_attributes(&mut self, pbag: &PropertyBag<'_>) -> ElementResult {
-        call_inner!(self, set_attributes, pbag)
-    }
-}
-
 impl Draw for Element {
     fn draw(
         &self,
@@ -628,20 +643,26 @@ impl fmt::Display for Element {
 
 macro_rules! e {
     ($name:ident, $element_type:ident) => {
-        pub fn $name(element_name: &QualName, id: Option<&str>, class: Option<&str>) -> Element {
-            Element::$element_type(Box::new(ElementInner {
-                element_name: element_name.clone(),
-                id: id.map(str::to_string),
-                class: class.map(str::to_string),
-                specified_values: Default::default(),
-                important_styles: Default::default(),
-                transform: Default::default(),
-                result: Ok(()),
-                values: ComputedValues::default(),
-                cond: true,
-                style_attr: String::new(),
-                element_impl: <$element_type>::default(),
-            }))
+        pub fn $name(
+            element_name: &QualName,
+            attributes: Attributes,
+            id: Option<String>,
+            class: Option<String>,
+        ) -> Element {
+            let mut element_impl = <$element_type>::default();
+
+            let result = element_impl.set_attributes(&attributes);
+
+            let element = Element::$element_type(Box::new(ElementInner::new(
+                element_name.clone(),
+                id,
+                class,
+                attributes,
+                result,
+                element_impl,
+            )));
+
+            element
         }
     };
 }
@@ -719,8 +740,12 @@ mod creators {
 
 use creators::*;
 
-type ElementCreateFn =
-    fn(element_name: &QualName, id: Option<&str>, class: Option<&str>) -> Element;
+type ElementCreateFn = fn(
+    element_name: &QualName,
+    attributes: Attributes,
+    id: Option<String>,
+    class: Option<String>,
+) -> Element;
 
 #[derive(Copy, Clone, PartialEq)]
 enum ElementCreateFlags {
