@@ -7,7 +7,7 @@ use cssparser::{BasicParseError, BasicParseErrorKind, ParseErrorKind, ToCss};
 use markup5ever::QualName;
 
 use crate::allowed_url::Fragment;
-use crate::node::RsvgNode;
+use crate::node::Node;
 
 /// A short-lived error.
 ///
@@ -73,12 +73,12 @@ impl<'a> From<BasicParseError<'a>> for ValueErrorKind {
 
 /// A complete error for an attribute and its erroneous value
 #[derive(Debug, Clone, PartialEq)]
-pub struct NodeError {
+pub struct ElementError {
     pub attr: QualName,
     pub err: ValueErrorKind,
 }
 
-impl error::Error for NodeError {
+impl error::Error for ElementError {
     fn description(&self) -> &str {
         match self.err {
             ValueErrorKind::UnknownProperty => "unknown property",
@@ -88,27 +88,61 @@ impl error::Error for NodeError {
     }
 }
 
-impl fmt::Display for NodeError {
+impl fmt::Display for ElementError {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         write!(f, "{:?}: {}", self.attr.expanded(), self.err)
     }
 }
 
+/// Errors returned when looking up a resource by URL reference.
 #[derive(Debug, Clone, PartialEq)]
 pub enum DefsLookupErrorKind {
+    /// Error when parsing an [`Href`].
+    ///
+    /// [`Href`]: allowed_url/enum.Href.html
     HrefError(HrefError),
+
+    /// Used when the public API tries to look up an external URL, which is not allowed.
+    ///
+    /// This catches the case where a public API wants to be misused to access an external
+    /// resource.  For example, `SvgHandle.has_sub("https://evil.com/phone_home#element_id") will
+    /// fail with this error.
     CannotLookupExternalReferences,
+
+    /// For internal use only.
+    ///
+    // FIXME: this is returned internally from Handle.lookup_node(), and gets translated
+    // to Ok(false).  Don't expose this internal code in the public API.
     NotFound,
 }
 
+/// Errors that can happen while rendering or measuring an SVG document.
 #[derive(Debug, Clone, PartialEq)]
 pub enum RenderingError {
+    /// A Cairo error happened during rendering.
     Cairo(cairo::Status),
+
+    /// There is a circular reference between elements.
+    // FIXME: should be internal only.
     CircularReference,
+
+    /// The maximum number of rendered objects was reached.
+    ///
+    /// Librsvg has a limit on the number of rendered objects, so that malicious
+    /// files cannot consume CPU time arbitrarily.
     InstancingLimit,
+
+    /// Tried to reference an SVG element from a fragment identifier that is incorrect.
     InvalidId(DefsLookupErrorKind),
+
+    // FIXME: unused.
     InvalidHref,
+
+    /// Not enough memory was available for rendering.
+    // FIXME: right now this is only returned from pixbuf_utils.rs
     OutOfMemory,
+
+    /// Cannot occur from librsvg_crate; this is just for the C API.
     HandleIsNotLoaded,
 }
 
@@ -139,7 +173,7 @@ impl From<cairo::Status> for RenderingError {
 pub enum AcquireError {
     LinkNotFound(Fragment),
     InvalidLinkType(Fragment),
-    CircularReference(RsvgNode),
+    CircularReference(Node),
     MaxReferencesExceeded,
 }
 
@@ -163,9 +197,9 @@ impl fmt::Display for AcquireError {
     }
 }
 
-/// Helper for converting `Result<O, E>` into `Result<O, NodeError>`
+/// Helper for converting `Result<O, E>` into `Result<O, ElementError>`
 ///
-/// A `NodeError` requires a `QualName` that corresponds to the attribute to which the
+/// A `ElementError` requires a `QualName` that corresponds to the attribute to which the
 /// error refers, plus the actual `ValueErrorKind` that describes the error.  However,
 /// parsing functions for attribute value types will want to return their own kind of
 /// error, instead of `ValueErrorKind`.  If that particular error type has an `impl
@@ -183,21 +217,21 @@ impl fmt::Display for AcquireError {
 /// ```
 ///
 /// The call to `.attribute(attr)` converts the `Result` from `parse_foo()` into a full
-/// `NodeError` with the provided `attr`.
+/// `ElementError` with the provided `attr`.
 pub trait AttributeResultExt<O> {
-    fn attribute(self, attr: QualName) -> Result<O, NodeError>;
+    fn attribute(self, attr: QualName) -> Result<O, ElementError>;
 }
 
 impl<O, E: Into<ValueErrorKind>> AttributeResultExt<O> for Result<O, E> {
-    fn attribute(self, attr: QualName) -> Result<O, NodeError> {
+    fn attribute(self, attr: QualName) -> Result<O, ElementError> {
         self.map_err(|e| e.into())
-            .map_err(|err| NodeError { attr, err })
+            .map_err(|err| ElementError { attr, err })
     }
 }
 
-/// Turns a short-lived `ParseError` into a long-lived `NodeError`
+/// Turns a short-lived `ParseError` into a long-lived `ElementError`
 impl<'i, O> AttributeResultExt<O> for Result<O, ParseError<'i>> {
-    fn attribute(self, attr: QualName) -> Result<O, NodeError> {
+    fn attribute(self, attr: QualName) -> Result<O, ElementError> {
         self.map_err(|e| {
             // FIXME: eventually, here we'll want to preserve the location information
 
@@ -212,13 +246,13 @@ impl<'i, O> AttributeResultExt<O> for Result<O, ParseError<'i>> {
                     tok.to_css(&mut s).unwrap(); // FIXME: what do we do with a fmt::Error?
                     s.push_str("'");
 
-                    NodeError {
+                    ElementError {
                         attr,
                         err: ValueErrorKind::Parse(s),
                     }
                 }
 
-                ParseErrorKind::Basic(BasicParseErrorKind::EndOfInput) => NodeError {
+                ParseErrorKind::Basic(BasicParseErrorKind::EndOfInput) => ElementError {
                     attr,
                     err: ValueErrorKind::parse_error("unexpected end of input"),
                 },
@@ -227,7 +261,7 @@ impl<'i, O> AttributeResultExt<O> for Result<O, ParseError<'i>> {
                     unreachable!("attribute parsers should not return errors for CSS rules")
                 }
 
-                ParseErrorKind::Custom(err) => NodeError { attr, err },
+                ParseErrorKind::Custom(err) => ElementError { attr, err },
             }
         })
     }
@@ -265,21 +299,55 @@ impl From<HrefError> for ValueErrorKind {
     }
 }
 
+/// Errors that can happen while loading an SVG document.
+///
+/// All of these codes are for unrecoverable errors that keep an SVG document from being
+/// fully loaded and parsed.  Note that SVG is very lenient with respect to document
+/// structure and the syntax of CSS property values; most errors there will not lead to a
+/// `LoadingError`.  To see those errors, you may want to set the `RSVG_LOG=1` environment
+/// variable.
+///
+/// I/O errors get reported in the `Glib` variant, since librsvg uses GIO internally for
+/// all input/output.
 #[derive(Debug, Clone)]
 pub enum LoadingError {
+    // FIXME: C API only
     NoDataPassedToParser,
+
+    /// XML syntax error.
     XmlParseError(String),
-    // Could not parse data: URL
+
+    // FIXME: this is OOM in libxml2; we shouldn't expose it.
     CouldNotCreateXmlParser,
+
+    /// A malformed or disallowed URL was used.
     BadUrl,
+
+    /// A `data:` URL could not be decoded.
     BadDataUrl,
+
+    // FIXME: used only if XML processing instruction cannot find the stylesheet.
     BadStylesheet,
+
+    /// An invalid stylesheet was used.
     BadCss,
+
+    /// A Cairo error happened during loading.
     Cairo(cairo::Status),
+
+    // FIXME: only used in load_image()
     EmptyData,
+
+    /// There are no SVG elements in the document.
     SvgHasNoElements,
+
+    /// The outermost element in the document is not `<svg>`.
     RootElementIsNotSvg,
+
+    /// Generally an I/O error, or another error from GIO.
     Glib(glib::Error),
+
+    // FIXME: only used internally when loading pixbufs, and temporarily in c_api.
     Unknown,
 }
 
