@@ -1,16 +1,22 @@
 //! The `filter` element.
 
+use cssparser::Parser;
 use markup5ever::{expanded_name, local_name, namespace_url, ns};
+use std::slice::Iter;
 
+use crate::allowed_url::Fragment;
+use crate::attributes::Attributes;
 use crate::bbox::BoundingBox;
 use crate::coord_units::CoordUnits;
+use crate::document::AcquiredNodes;
 use crate::drawing_ctx::DrawingCtx;
-use crate::element::{Draw, ElementResult, SetAttributes};
+use crate::element::{Draw, Element, ElementResult, SetAttributes};
 use crate::error::ValueErrorKind;
+use crate::iri::IRI;
 use crate::length::*;
+use crate::node::{Node, NodeBorrow};
 use crate::parsers::{Parse, ParseValue};
 use crate::properties::ComputedValues;
-use crate::property_bag::PropertyBag;
 use crate::rect::Rect;
 use crate::transform::Transform;
 
@@ -61,20 +67,7 @@ impl Filter {
 
         let mut bbox = BoundingBox::new();
 
-        // transform is set up in FilterContext::new() in such a way that for
-        // filterunits == ObjectBoundingBox it includes scaling to correct width, height and
-        // this is why width and height are set to 1, 1 (and for filterunits ==
-        // UserSpaceOnUse, transform doesn't include scaling because in this case the correct
-        // width, height already happens to be the viewbox width, height).
-        //
-        // It's done this way because with ObjectBoundingBox, non-percentage values are supposed to
-        // represent the fractions of the referenced node, and with width and height = 1, 1 this
-        // works out exactly like that.
-        let params = if self.filterunits == CoordUnits::ObjectBoundingBox {
-            draw_ctx.push_view_box(1.0, 1.0)
-        } else {
-            draw_ctx.get_view_params()
-        };
+        let params = draw_ctx.push_coord_units(self.filterunits);
 
         // With filterunits == ObjectBoundingBox, lengths represent fractions or percentages of the
         // referencing node. No units are allowed (it's checked during attribute parsing).
@@ -111,9 +104,9 @@ impl Filter {
 }
 
 impl SetAttributes for Filter {
-    fn set_attributes(&mut self, pbag: &PropertyBag<'_>) -> ElementResult {
+    fn set_attributes(&mut self, attrs: &Attributes) -> ElementResult {
         // Parse filterUnits first as it affects x, y, width, height checks.
-        let result = pbag
+        let result = attrs
             .iter()
             .find(|(attr, _)| attr.expanded() == expanded_name!("", "filterUnits"))
             .and_then(|(attr, value)| attr.parse(value).ok());
@@ -159,7 +152,7 @@ impl SetAttributes for Filter {
         };
 
         // Parse the rest of the attributes.
-        for (attr, value) in pbag.iter() {
+        for (attr, value) in attrs.iter() {
             match attr.expanded() {
                 expanded_name!("", "x") => {
                     self.x = attr.parse_and_validate(value, check_units_horizontal)?
@@ -185,3 +178,112 @@ impl SetAttributes for Filter {
 }
 
 impl Draw for Filter {}
+
+#[derive(Debug, Clone, PartialEq)]
+pub enum FilterValue {
+    URL(Fragment),
+}
+#[derive(Debug, Clone, PartialEq)]
+pub struct FilterValueList(Vec<FilterValue>);
+
+impl Default for FilterValueList {
+    fn default() -> FilterValueList {
+        FilterValueList(vec![])
+    }
+}
+
+impl FilterValueList {
+    pub fn is_empty(&self) -> bool {
+        self.0.is_empty()
+    }
+
+    pub fn iter(&self) -> Iter<FilterValue> {
+        self.0.iter()
+    }
+
+    /// Check that at least one filter URI exists and that all contained
+    /// URIs reference existing <filter> elements.
+    pub fn is_applicable(&self, node: &Node, acquired_nodes: &mut AcquiredNodes) -> bool {
+        if self.is_empty() {
+            return false;
+        }
+
+        self.0.iter().all(|filter| match filter {
+            FilterValue::URL(filter_uri) => match acquired_nodes.acquire(filter_uri) {
+                Ok(acquired) => {
+                    let filter_node = acquired.get();
+
+                    match *filter_node.borrow_element() {
+                        Element::Filter(_) => true,
+                        _ => {
+                            rsvg_log!(
+                                "element {} will not be filtered since \"{}\" is not a filter",
+                                node,
+                                filter_uri,
+                            );
+                            false
+                        }
+                    }
+                }
+                _ => {
+                    rsvg_log!(
+                        "element {} will not be filtered since its filter \"{}\" was not found",
+                        node,
+                        filter_uri,
+                    );
+                    false
+                }
+            },
+        })
+    }
+}
+
+impl Parse for FilterValueList {
+    fn parse<'i>(parser: &mut Parser<'i, '_>) -> Result<Self, crate::error::ParseError<'i>> {
+        let mut result = FilterValueList::default();
+
+        loop {
+            let state = parser.state();
+
+            if let Ok(IRI::Resource(uri)) = parser.try_parse(|p| IRI::parse(p)) {
+                result.0.push(FilterValue::URL(uri));
+            } else {
+                parser.reset(&state);
+                let token = parser.next()?.clone();
+                return Err(parser.new_basic_unexpected_token_error(token).into());
+            }
+
+            if parser.is_exhausted() {
+                break;
+            }
+        }
+
+        Ok(result)
+    }
+}
+
+#[cfg(test)]
+mod tests {
+    use super::*;
+
+    #[test]
+    fn parses_filter_value_list() {
+        let f1 = Fragment::new(Some("foo.svg".to_string()), "bar".to_string());
+        let f2 = Fragment::new(Some("test.svg".to_string()), "baz".to_string());
+        assert_eq!(
+            FilterValueList::parse_str("url(foo.svg#bar) url(test.svg#baz)"),
+            Ok(FilterValueList(vec![
+                FilterValue::URL(f1),
+                FilterValue::URL(f2)
+            ]))
+        );
+    }
+
+    #[test]
+    fn detects_invalid_filter_value_list() {
+        assert!(FilterValueList::parse_str("none").is_err());
+        assert!(FilterValueList::parse_str("").is_err());
+        assert!(FilterValueList::parse_str("fail").is_err());
+        assert!(FilterValueList::parse_str("url(#test) none").is_err());
+    }
+}
