@@ -6,6 +6,8 @@ use crate::error::RenderingError;
 /// An enumeration of errors that can occur during filter primitive rendering.
 #[derive(Debug, Clone, Copy, Eq, PartialEq)]
 pub enum FilterError {
+    /// The units on the filter bounds are invalid
+    InvalidUnits,
     /// The filter was passed invalid input (the `in` attribute).
     InvalidInput,
     /// The filter input surface has an unsuccessful status.
@@ -28,6 +30,10 @@ impl Error for FilterError {}
 impl fmt::Display for FilterError {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
         match *self {
+            FilterError::InvalidUnits => write!(
+                f,
+                "unit identifiers are not allowed with primitiveUnits set to objectBoundingBox"
+            ),
             FilterError::InvalidInput => write!(f, "invalid value of the `in` attribute"),
             FilterError::BadInputSurfaceStatus(ref status) => {
                 write!(f, "invalid status of the input surface: {}", status)
