@@ -238,7 +238,7 @@ impl Parse for FontSize {
     fn parse<'i>(parser: &mut Parser<'i, '_>) -> Result<FontSize, ParseError<'i>> {
         parser
             .try_parse(|p| Length::<Both>::parse(p))
-            .and_then(|l| Ok(FontSize::Value(l)))
+            .map(FontSize::Value)
             .or_else(|_| {
                 Ok(parse_identifiers!(
                     parser,
@@ -377,7 +377,7 @@ impl Parse for LetterSpacing {
     fn parse<'i>(parser: &mut Parser<'i, '_>) -> Result<LetterSpacing, ParseError<'i>> {
         parser
             .try_parse(|p| Length::<Horizontal>::parse(p))
-            .and_then(|l| Ok(LetterSpacing::Value(l)))
+            .map(LetterSpacing::Value)
             .or_else(|_| {
                 Ok(parse_identifiers!(
                     parser,
@@ -435,7 +435,9 @@ impl Parse for LineHeight {
                 if cow.eq_ignore_ascii_case("normal") {
                     Ok(LineHeight::Normal)
                 } else {
-                    Err(parser.new_basic_unexpected_token_error(token.clone()))?
+                    Err(parser
+                        .new_basic_unexpected_token_error(token.clone())
+                        .into())
                 }
             }
 
@@ -450,7 +452,7 @@ impl Parse for LineHeight {
                 Ok(LineHeight::Length(Length::<Both>::parse(parser)?))
             }
 
-            _ => Err(parser.new_basic_unexpected_token_error(token))?,
+            _ => Err(parser.new_basic_unexpected_token_error(token).into()),
         }
     }
 }
