@@ -9,6 +9,7 @@ use markup5ever::{expanded_name, local_name, namespace_url, ns};
 use crate::allowed_url::Fragment;
 use crate::angle::Angle;
 use crate::aspect_ratio::*;
+use crate::attributes::Attributes;
 use crate::bbox::BoundingBox;
 use crate::document::AcquiredNodes;
 use crate::drawing_ctx::DrawingCtx;
@@ -21,7 +22,6 @@ use crate::node::{CascadedValues, Node, NodeBorrow, NodeDraw};
 use crate::parsers::{Parse, ParseValue};
 use crate::path_builder::{arc_segment, ArcParameterization, CubicBezierCurve, Path, PathCommand};
 use crate::properties::ComputedValues;
-use crate::property_bag::PropertyBag;
 use crate::rect::Rect;
 use crate::transform::Transform;
 use crate::viewbox::*;
@@ -135,7 +135,7 @@ impl Marker {
         }
 
         let params = if let Some(vbox) = self.vbox {
-            if vbox.0.is_empty() {
+            if vbox.is_empty() {
                 return Ok(draw_ctx.empty_bbox());
             }
 
@@ -143,7 +143,7 @@ impl Marker {
                 .aspect
                 .compute(&vbox, &Rect::from_size(marker_width, marker_height));
 
-            let (vb_width, vb_height) = vbox.0.size();
+            let (vb_width, vb_height) = vbox.size();
             transform = transform.pre_scale(r.width() / vb_width, r.height() / vb_height);
 
             draw_ctx.push_view_box(vb_width, vb_height)
@@ -161,7 +161,7 @@ impl Marker {
         } else {
             Some(
                 self.vbox
-                    .map_or_else(|| Rect::from_size(marker_width, marker_height), |vb| vb.0),
+                    .map_or_else(|| Rect::from_size(marker_width, marker_height), |vb| *vb),
             )
         };
 
@@ -176,8 +176,8 @@ impl Marker {
 }
 
 impl SetAttributes for Marker {
-    fn set_attributes(&mut self, pbag: &PropertyBag<'_>) -> ElementResult {
-        for (attr, value) in pbag.iter() {
+    fn set_attributes(&mut self, attrs: &Attributes) -> ElementResult {
+        for (attr, value) in attrs.iter() {
             match attr.expanded() {
                 expanded_name!("", "markerUnits") => self.units = attr.parse(value)?,
                 expanded_name!("", "refX") => self.ref_x = attr.parse(value)?,
