@@ -1,6 +1,8 @@
 //! Various utilities for working with Cairo image surfaces.
 
+use std::mem;
 use std::ops::DerefMut;
+use std::slice;
 
 pub mod iterators;
 pub mod shared_surface;
@@ -18,6 +20,27 @@ use rgb::alt::ARGB8;
 #[cfg(target_endian = "big")]
 pub type CairoARGB = ARGB8;
 
+/// Analogous to `rgb::FromSlice`, to convert from `[T]` to `[CairoARGB]`
+pub trait AsCairoARGB<T: Copy> {
+    /// Reinterpret slice as `CairoARGB` pixels.
+    fn as_cairo_argb(&self) -> &[CairoARGB];
+
+    /// Reinterpret mutable slice as `CairoARGB` pixels.
+    fn as_cairo_argb_mut(&mut self) -> &mut [CairoARGB];
+}
+
+impl<T: Copy> AsCairoARGB<T> for [T] {
+    fn as_cairo_argb(&self) -> &[CairoARGB] {
+        debug_assert_eq!(4, mem::size_of::<CairoARGB>() / mem::size_of::<T>());
+        unsafe { slice::from_raw_parts(self.as_ptr() as *const _, self.len() / 4) }
+    }
+
+    fn as_cairo_argb_mut(&mut self) -> &mut [CairoARGB] {
+        debug_assert_eq!(4, mem::size_of::<CairoARGB>() / mem::size_of::<T>());
+        unsafe { slice::from_raw_parts_mut(self.as_ptr() as *mut _, self.len() / 4) }
+    }
+}
+
 /// A pixel consisting of R, G, B and A values.
 #[derive(Debug, Clone, Copy, Eq, PartialEq, Hash)]
 pub struct Pixel {
@@ -46,6 +69,8 @@ pub trait ImageSurfaceDataExt: DerefMut<Target = [u8]> {
     #[inline]
     fn set_pixel(&mut self, stride: usize, pixel: Pixel, x: u32, y: u32) {
         let value = pixel.to_u32();
+
+        #[allow(clippy::cast_ptr_alignment)]
         unsafe {
             *(&mut self[y as usize * stride + x as usize * 4] as *mut u8 as *mut u32) = value;
         }
